Introduction
============

The ``debops.locales`` Ansible role manages localization and
internationalization configuration, used by the ``locales`` Debian package. The
role can be used as a dependency of other Ansible roles to ensure that the
localization is properly configured on the host.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.2.0``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops.locales

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
